@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Part of the PsychoPy library
-# Copyright (C) 2002-2018 Jonathan Peirce (C) 2019 Open Science Tools Ltd.
+# Copyright (C) 2002-2018 Jonathan Peirce (C) 2019-2020 Open Science Tools Ltd.
 # Distributed under the terms of the GNU General Public License (GPL).
 
 """Dialog classes for the Builder Code component
@@ -10,15 +10,14 @@
 
 from __future__ import absolute_import, division, print_function
 from builtins import str
+import sys
 
 import keyword
 import wx
+# import wx.lib.agw.aui as aui
 from collections import OrderedDict
-
-try:
-    from wx.lib.agw import flatnotebook
-except ImportError:  # was here wx<4.0:
-    from wx.lib import flatnotebook
+from psychopy.experiment.components.code import CodeComponent
+from ...themes import ThemeMixin
 
 from psychopy.constants import PY3
 
@@ -39,7 +38,7 @@ class DlgCodeComponentProperties(wx.Dialog):
               | wx.DIALOG_NO_PARENT)
 
     def __init__(self, frame, title, params, order,
-                 helpUrl=None, suppressTitles=True, size=wx.DefaultSize,
+                 helpUrl=None, suppressTitles=True, size=(800,400),
                  style=_style, editing=False, depends=[],
                  timeout=None):
 
@@ -47,7 +46,9 @@ class DlgCodeComponentProperties(wx.Dialog):
         localizedTitle = title.replace(' Properties',
                                        _translate(' Properties'))
         wx.Dialog.__init__(self, None, -1, localizedTitle,
-                           size=size, style=style)
+                           size=size, style=self._style)
+        self.SetTitle(localizedTitle)  # use localized title
+        # self.panel = wx.Panel(self)
         self.frame = frame
         self.app = frame.app
         self.helpUrl = helpUrl
@@ -56,8 +57,6 @@ class DlgCodeComponentProperties(wx.Dialog):
         self.title = title
         self.timeout = timeout
         self.warningsDict = {}  # to store warnings for all fields
-        # keep localized title to update dialog's properties later.
-        self.localizedTitle = localizedTitle
         self.codeBoxes = {}
         self.tabs = OrderedDict()
 
@@ -66,15 +65,12 @@ class DlgCodeComponentProperties(wx.Dialog):
             makeValid = self.frame.exp.namespace.makeValid
             self.params['name'].val = makeValid(params['name'].val)
 
-        agwStyle = flatnotebook.FNB_NO_X_BUTTON
-        if hasattr(flatnotebook, "FNB_NAV_BUTTONS_WHEN_NEEDED"):
-            # not available in wxPython 2.8
-            agwStyle |= flatnotebook.FNB_NAV_BUTTONS_WHEN_NEEDED
-        if hasattr(flatnotebook, "FNB_NO_TAB_FOCUS"):
-            # not available in wxPython 2.8.10
-            agwStyle |= flatnotebook.FNB_NO_TAB_FOCUS
-        self.codeNotebook = flatnotebook.FlatNotebook(self, wx.ID_ANY,
-                                                      style=agwStyle)
+        self.codeNotebook = wx.Notebook(self)
+        # in AUI notebook the labels are blurry on retina mac
+        #   and the close-tab buttons are hard to kill
+        #   self.codeNotebook = aui.AuiNotebook(self)
+        # in FlatNoteBook the tab controls (left,right,close) are ugly on mac
+        #   and also can't be killed
 
         openToPage = None
         tabN = -1
@@ -94,10 +90,16 @@ class DlgCodeComponentProperties(wx.Dialog):
                                                  style=wx.ALIGN_RIGHT)
                 self.nameOKlabel.SetForegroundColour(wx.RED)
             elif paramName == 'Code Type':
+                # Create code type choice menu
                 _codeTypes = self.params['Code Type'].allowedVals
+                _selectedCodeType = self.params['Code Type'].val
+                _selectedCodeTypeIndex = _codeTypes.index(_selectedCodeType)
                 self.codeTypeMenu = wx.Choice(self, choices=_codeTypes)
-                self.codeTypeMenu.SetSelection(
-                    _codeTypes.index(_codeTypes[hasMetapensiero - 2]))
+                # If user does not have metapensiero but codetype is auto-js, revert to (Py?)
+                if not hasMetapensiero and _selectedCodeType.lower() == 'auto->js':
+                    _selectedCodeTypeIndex -= 1
+                # Set selection to value stored in self params
+                self.codeTypeMenu.SetSelection(_selectedCodeTypeIndex)
                 self.codeTypeMenu.Bind(wx.EVT_CHOICE, self.onCodeChoice)
                 self.codeTypeName = wx.StaticText(self, wx.ID_ANY,
                                                   _translate(param.label))
@@ -108,6 +110,7 @@ class DlgCodeComponentProperties(wx.Dialog):
                     _panel = self.tabs[tabName]
                 else:
                     _panel = wx.Panel(self.codeNotebook, wx.ID_ANY)
+                    _panel.app = self.app
                     self.tabs[tabName] = _panel
                     tabN += 1
 
@@ -133,10 +136,9 @@ class DlgCodeComponentProperties(wx.Dialog):
         self.okButton.SetDefault()
         self.cancelButton = wx.Button(self, wx.ID_CANCEL,
                                       _translate(" Cancel "))
-        self.__set_properties()
         self.__do_layout()
         if openToPage is None:
-            openToPage = 0
+            openToPage = 1
         self.codeNotebook.SetSelection(openToPage)
         self.Update()
         self.Bind(wx.EVT_BUTTON, self.helpButtonHandler, self.helpButton)
@@ -219,15 +221,17 @@ class DlgCodeComponentProperties(wx.Dialog):
         Calls translation and updates to visible windows
         """
         prevCodeType, param = self.codeChoice
-
+        # If user doesn't have metapensiero and current choice is auto-js...
         if not hasMetapensiero and param.val.lower() == "auto->js" :
+            # Throw up error dlg instructing to get metapensiero
             msg = ("\nPy to JS auto-translation requires the metapensiero library.\n"
                    "Available for Python 3.5+.\n")
             dlg = CodeOverwriteDialog(self, -1, "Warning: requires the metapensiero library", msg)
             dlg.ShowModal()
+            # Revert to previous choice
             self.undoCodeTypeChoice(prevCodeType)
             return
-
+        # Translate from previous language to new, make sure correct box is visible
         self.translateCode(event, prevCodeType, param.val)
         self.updateVisibleCode(event)
 
@@ -248,20 +252,25 @@ class DlgCodeComponentProperties(wx.Dialog):
         newCodeType : str
             New code type selected
         """
+        # If new codetype is not auto-js, terminate function
         if not newCodeType.lower() == "auto->js":
             return
-
+        # If code type has changed and previous code type isn't auto-js...
         if prevCodeType.lower() != 'auto->js' and self.codeChangeDetected():
+            # Throw up a warning dlg to alert user of overwriting
             msg = ("\nAuto-JS translation will overwrite your existing JavaScript code.\n"
                    "Press OK to continue, or Cancel.\n")
             dlg = CodeOverwriteDialog(self, -1, "Warning: Python to JavaScript Translation", msg)
             retVal = dlg.ShowModal()
+            # When window closes, if OK was not clicked revert to previous codetype
             if not retVal == wx.ID_OK:
                 self.undoCodeTypeChoice(prevCodeType)
                 return
-
+        # For each codebox...
         for boxName in self.codeBoxes:
+            # If it is not JS...
             if 'JS' not in boxName:
+                # Traslate to JS
                 self.runTranslation(boxName)
 
         if event:
@@ -336,21 +345,23 @@ class DlgCodeComponentProperties(wx.Dialog):
 
         for boxName in self.codeBoxes:
             self.readOnlyCodeBox(codeType.lower() == 'auto->js')
+            # If type is both or autojs, show split codebox
             if codeType.lower() in ['both', 'auto->js']:
                 self.codeBoxes[boxName].Show()
+            # If type is JS, hide the non-JS box
             elif codeType == 'JS':
-                # user only wants JS code visible
                 if 'JS' in boxName:
                     self.codeBoxes[boxName].Show()
                 else:
                     self.codeBoxes[boxName].Hide()
+            # If type is Py, hide the JS box
             else:
                 # user only wants Py code visible
                 if 'JS' in boxName:
                     self.codeBoxes[boxName].Hide()
                 else:
                     self.codeBoxes[boxName].Show()
-
+        # Name codebox tabs
         for thisTabname in self.tabs:
             self.tabs[thisTabname].Layout()
 
@@ -366,11 +377,6 @@ class DlgCodeComponentProperties(wx.Dialog):
         """
         self.Validate()
 
-    def __set_properties(self):
-
-        self.SetTitle(self.localizedTitle)  # use localized title
-        self.SetSize((640, 480))
-
     def __do_layout(self, show=False):
         self.updateVisibleCode()
         for tabName in self.tabs:
@@ -385,14 +391,16 @@ class DlgCodeComponentProperties(wx.Dialog):
             panel.SetSizer(sizer)
             tabLabel = _translate(tabName)
             # Add a visual indicator when tab contains code
-            if (self.params.get(pyName).val or self.params.get(jsName).val):
+            emptyCodeComp = CodeComponent('', '') # Spawn empty code component
+            # If code tab is not empty and not the same as in empty code component, add an asterisk to tab name
+            if (self.params.get(pyName).val or self.params.get(jsName).val) and not (self.params.get(pyName).val == emptyCodeComp.params.get(pyName).val or self.params.get(jsName).val == emptyCodeComp.params.get(jsName).val):
                 tabLabel += ' *'
             self.codeNotebook.AddPage(panel, tabLabel)
 
         nameSizer = wx.BoxSizer(wx.HORIZONTAL)
         nameSizer.Add(self.nameLabel, 0, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 10)
         nameSizer.Add(self.componentName,
-                      flag=wx.EXPAND | wx.ALL | wx.ALIGN_CENTER_VERTICAL,
+                      flag=wx.EXPAND | wx.ALL,
                       border=10, proportion=1)
         nameSizer.Add(self.nameOKlabel, 0, wx.ALL, 10)
         nameSizer.Add(self.codeTypeName,
@@ -403,10 +411,24 @@ class DlgCodeComponentProperties(wx.Dialog):
         buttonSizer = wx.BoxSizer(wx.HORIZONTAL)
         mainSizer.Add(nameSizer)
         mainSizer.Add(self.codeNotebook, 1, wx.EXPAND | wx.ALL, 10)
-        buttonSizer.Add(self.helpButton, 0, wx.RIGHT, 10)
-        buttonSizer.Add(self.okButton, 0, wx.LEFT, 10)
-        buttonSizer.Add(self.cancelButton, 0, 0, 0)
-        mainSizer.Add(buttonSizer, 0, wx.ALL | wx.ALIGN_RIGHT, 5)
+
+        buttonSizer.Add(self.helpButton, 0,
+                        wx.ALL | wx.RIGHT | wx.ALIGN_CENTER_VERTICAL, 10)
+        buttonSizer.AddStretchSpacer()
+        if sys.platform == 'darwin':
+            buttonSizer.Add(self.cancelButton, 0,
+                            wx.ALL | wx.RIGHT | wx.ALIGN_CENTER_VERTICAL,
+                            border=3)
+            buttonSizer.Add(self.okButton, 0,
+                            wx.ALL | wx.RIGHT | wx.ALIGN_CENTER_VERTICAL,
+                            border=3)
+        else:
+            buttonSizer.Add(self.okButton, 0,
+                            wx.ALL | wx.RIGHT | wx.ALIGN_CENTER_VERTICAL, border=3)
+            buttonSizer.Add(self.cancelButton, 0,
+                            wx.ALL | wx.RIGHT | wx.ALIGN_CENTER_VERTICAL, border=3)
+
+        mainSizer.Add(buttonSizer, 0, wx.ALL | wx.RIGHT | wx.EXPAND, 5)
         self.SetSizer(mainSizer)
         self.Layout()
         self.Center()
@@ -438,7 +460,7 @@ class DlgCodeComponentProperties(wx.Dialog):
         self.app.followLink(url=self.helpUrl)
 
 
-class CodeBox(BaseCodeEditor):
+class CodeBox(BaseCodeEditor, ThemeMixin):
     # this comes mostly from the wxPython demo styledTextCtrl 2
 
     def __init__(self, parent, ID, prefs,
@@ -452,24 +474,32 @@ class CodeBox(BaseCodeEditor):
         BaseCodeEditor.__init__(self, parent, ID, pos, size, style)
 
         self.parent = parent
-        self.prefs = prefs
+        self.app = parent.app
+        self.prefs = prefs.coder
+        self.appData = prefs.appData
+        self.paths = prefs.paths
         self.params = params
         self.codeType = codeType
-        self.SetLexer(wx.stc.STC_LEX_PYTHON)
-        self.SetKeyWords(0, " ".join(keyword.kwlist))
+        lexers = {
+            'Py': wx.stc.STC_LEX_PYTHON,
+            'JS': wx.stc.STC_LEX_CPP,
+            'txt': wx.stc.STC_LEX_CONTAINER
+        }
+        self.SetLexer(lexers[codeType])
 
         self.SetProperty("fold", "1")
         # 4 means 'tabs are bad'; 1 means 'flag inconsistency'
         self.SetProperty("tab.timmy.whinge.level", "4")
-        self.SetViewWhiteSpace(self.prefs.appData['coder']['showWhitespace'])
-        self.SetViewEOL(self.prefs.appData['coder']['showEOLs'])
+        self.SetViewWhiteSpace(self.appData['coder']['showWhitespace'])
+        self.SetViewEOL(self.appData['coder']['showEOLs'])
 
         self.Bind(wx.stc.EVT_STC_MARGINCLICK, self.OnMarginClick)
         self.SetIndentationGuides(False)
 
         self.Bind(wx.EVT_KEY_DOWN, self.OnKeyPressed)
 
-        self.setupStyles()
+        # apply the theme to the lexer
+        self._applyAppTheme()
 
     def OnKeyPressed(self, event):
         keyCode = event.GetKeyCode()
@@ -493,83 +523,6 @@ class CodeBox(BaseCodeEditor):
 
         event.Skip()
 
-    def setupStyles(self):
-
-        if wx.Platform == '__WXMSW__':
-            faces = {'size': 10}
-        elif wx.Platform == '__WXMAC__':
-            faces = {'size': 14}
-        else:
-            faces = {'size': 12}
-        if self.prefs.coder['codeFontSize']:
-            faces['size'] = int(self.prefs.coder['codeFontSize'])
-        faces['small'] = faces['size'] - 2
-        # Global default styles for all languages
-        # ,'Arial']  # use arial as backup
-        faces['code'] = self.prefs.coder['codeFont']
-        # ,'Arial']  # use arial as backup
-        faces['comment'] = self.prefs.coder['commentFont']
-        self.StyleSetSpec(wx.stc.STC_STYLE_DEFAULT,
-                          "face:%(code)s,size:%(size)d" % faces)
-        self.StyleClearAll()  # Reset all to be like the default
-
-        # Global default styles for all languages
-        self.StyleSetSpec(wx.stc.STC_STYLE_DEFAULT,
-                          "face:%(code)s,size:%(size)d" % faces)
-        self.StyleSetSpec(wx.stc.STC_STYLE_LINENUMBER,
-                          "back:#C0C0C0,face:%(code)s,size:%(small)d" % faces)
-        self.StyleSetSpec(wx.stc.STC_STYLE_CONTROLCHAR,
-                          "face:%(comment)s" % faces)
-        self.StyleSetSpec(wx.stc.STC_STYLE_BRACELIGHT,
-                          "fore:#FFFFFF,back:#0000FF,bold")
-        self.StyleSetSpec(wx.stc.STC_STYLE_BRACEBAD,
-                          "fore:#000000,back:#FF0000,bold")
-
-        # Python styles
-        # Default
-        self.StyleSetSpec(wx.stc.STC_P_DEFAULT,
-                          "fore:#000000,face:%(code)s,size:%(size)d" % faces)
-        # Comments
-        spec = "fore:#007F00,face:%(comment)s,size:%(size)d"
-        self.StyleSetSpec(wx.stc.STC_P_COMMENTLINE, spec % faces)
-        # Number
-        self.StyleSetSpec(wx.stc.STC_P_NUMBER,
-                          "fore:#007F7F,size:%(size)d" % faces)
-        # String
-        self.StyleSetSpec(wx.stc.STC_P_STRING,
-                          "fore:#7F007F,face:%(code)s,size:%(size)d" % faces)
-        # Single quoted string
-        self.StyleSetSpec(wx.stc.STC_P_CHARACTER,
-                          "fore:#7F007F,face:%(code)s,size:%(size)d" % faces)
-        # Keyword
-        self.StyleSetSpec(wx.stc.STC_P_WORD,
-                          "fore:#00007F,bold,size:%(size)d" % faces)
-        # Triple quotes
-        self.StyleSetSpec(wx.stc.STC_P_TRIPLE,
-                          "fore:#7F0000,size:%(size)d" % faces)
-        # Triple double quotes
-        self.StyleSetSpec(wx.stc.STC_P_TRIPLEDOUBLE,
-                          "fore:#7F0000,size:%(size)d" % faces)
-        # Class name definition
-        self.StyleSetSpec(wx.stc.STC_P_CLASSNAME,
-                          "fore:#0000FF,bold,underline,size:%(size)d" % faces)
-        # Function or method name definition
-        self.StyleSetSpec(wx.stc.STC_P_DEFNAME,
-                          "fore:#007F7F,bold,size:%(size)d" % faces)
-        # Operators
-        self.StyleSetSpec(wx.stc.STC_P_OPERATOR, "bold,size:%(size)d" % faces)
-        # Identifiers
-        self.StyleSetSpec(wx.stc.STC_P_IDENTIFIER,
-                          "fore:#000000,face:%(code)s,size:%(size)d" % faces)
-        # Comment-blocks
-        self.StyleSetSpec(wx.stc.STC_P_COMMENTBLOCK,
-                          "fore:#7F7F7F,size:%(size)d" % faces)
-        # End of line where string is not closed
-        spec = "fore:#000000,face:%(code)s,back:#E0C0E0,eol,size:%(size)d"
-        self.StyleSetSpec(wx.stc.STC_P_STRINGEOL, spec % faces)
-
-        self.SetCaretForeground("BLUE")
-
     def setStatus(self, status):
         if status == 'error':
             color = (255, 210, 210, 255)
@@ -621,7 +574,7 @@ class CodeOverwriteDialog(wx.Dialog):
 
         # Set divider
         line = wx.StaticLine(self, wx.ID_ANY, size=(20, -1), style=wx.LI_HORIZONTAL)
-        sizer.Add(line, 0, wx.GROW | wx.ALIGN_CENTER_VERTICAL | wx.RIGHT | wx.TOP, 5)
+        sizer.Add(line, 0, wx.GROW | wx.RIGHT | wx.TOP, 5)
 
         # Set buttons
         btnsizer = wx.StdDialogButtonSizer()
