@@ -65,8 +65,8 @@ class ScriptProcess(object):
 
     def runFile(self, event=None, fileName=None):
         """Begin new process to run experiment."""
-        self.app.showRunner()
         fullPath = fileName.replace('.psyexp', '_lastrun.py')
+        wx.BeginBusyCursor()
 
         # provide a running... message
         self.app.runner.stdOut.write((u"## Running: {} ##".format(fullPath)).center(80, "#")+"\n")
@@ -123,12 +123,16 @@ class ScriptProcess(object):
 
     def onProcessEnded(self, event=None):
         """Perform when script has finished running."""
+        try:
+            wx.EndBusyCursor()
+        except wx._core.wxAssertionError:
+            pass
         self._stdoutThread.exit = True
         time.sleep(0.1)  # give time for the buffers to finish writing?
         buff = self._stdoutThread.getBuffer()
         self.app.runner.stdOut.write(buff)
         self.app.runner.stdOut.flush()
-        self.app.runner.showRunner()
+        self.app.runner.Show()
 
         self.scriptProcess = None
         self.Bind(wx.EVT_IDLE, None)
