@@ -43,6 +43,7 @@ _localized = {'expName': _translate("Experiment name"),
               'Enable Escape':  _translate("Enable Escape key"),
               'Experiment info':  _translate("Experiment info"),
               'Data filename':  _translate("Data filename"),
+              'Data file delimiter':  _translate("Data file delimeter"),
               'Full-screen window':  _translate("Full-screen window"),
               'Window size (pixels)':  _translate("Window size (pixels)"),
               'Screen': _translate('Screen'),
@@ -100,7 +101,7 @@ class SettingsComponent(object):
                  blendMode='avg',
                  saveXLSXFile=False, saveCSVFile=False,
                  saveWideCSVFile=True, savePsydatFile=True,
-                 savedDataFolder='',
+                 savedDataFolder='', savedDataDelim='auto',
                  useVersion='',
                  filename=None, exportHTML='on Sync'):
         self.type = 'Settings'
@@ -241,6 +242,12 @@ class SettingsComponent(object):
             hint=_translate("Code to create your custom file name base. Don"
                             "'t give a file extension - this will be added."),
             label=_localized["Data filename"], categ='Data')
+        self.params['Data file delimiter'] = Param(
+            savedDataDelim, valType='str',
+            allowedVals=['auto', 'comma', 'semicolon', 'tab'],
+            hint=_translate("What symbol should the data file use to separate columns? ""Auto"" will select a delimiter automatically from the filename."),
+            label=_translate("Data file delimiter"), categ='Data'
+        )
         self.params['Save log file'] = Param(
             saveLogFile, valType='bool', allowedTypes=[],
             hint=_translate("Save a detailed log (more detailed than the "
@@ -279,9 +286,13 @@ class SettingsComponent(object):
         #     hint=_translate("The ID of this project (e.g. 5bqpc)"),
         #     label="OSF Project ID", categ='Online')
         self.params['HTML path'] = Param(
-            'html', valType='str', allowedTypes=[],
+            '', valType='str', allowedTypes=[],
             hint=_translate("Place the HTML files will be saved locally "),
             label="Output path", categ='Online')
+        self.params['Resources'] = Param(
+            [], valType='fileList', allowedTypes=[],
+            hint=_translate("Any additional resources needed"),
+            label="Additional Resources", categ='Online')
         self.params['Completed URL'] = Param(
             '', valType='str',
             hint=_translate("Where should participants be redirected after the experiment on completion\n"
@@ -558,9 +569,11 @@ class SettingsComponent(object):
                     "import * as core from './lib/core{version}.js';\n"
                     "import {{ TrialHandler }} from './lib/data{version}.js';\n"
                     "import {{ Scheduler }} from './lib/util{version}.js';\n"
-                    "import * as util from './lib/util{version}.js';\n"
                     "import * as visual from './lib/visual{version}.js';\n"
                     "import * as sound from './lib/sound{version}.js';\n"
+                    "import * as util from './lib/util{version}.js';\n"
+                    "//some handy aliases as in the psychopy scripts;\n"
+                    "const {{ abs, sin, cos, PI: pi, sqrt }} = Math;\n"
                     "\n").format(version=versionStr)
             buff.writeIndentedLines(code)
 
@@ -630,7 +643,7 @@ class SettingsComponent(object):
         if self.params['Show info dlg'].val:
             buff.writeIndentedLines(
                 "dlg = gui.DlgFromDict(dictionary=expInfo, "
-                "sortKeys={}, title=expName)\n"
+                "sort_keys={}, title=expName)\n"
                 "if dlg.OK == False:\n"
                 "    core.quit()  # user pressed cancel\n"
                 .format(sorting)
@@ -807,7 +820,8 @@ class SettingsComponent(object):
         buff.writeIndented("# these shouldn't be strictly necessary "
                            "(should auto-save)\n")
         if self.params['Save wide csv file'].val:
-            buff.writeIndented("thisExp.saveAsWideText(filename+'.csv')\n")
+            buff.writeIndented("thisExp.saveAsWideText(filename+'.csv', "
+                               "delim={})\n".format(self.params['Data file delimiter']))
         if self.params['Save psydat file'].val:
             buff.writeIndented("thisExp.saveAsPickle(filename)\n")
         if self.params['Save log file'].val:
@@ -819,22 +833,21 @@ class SettingsComponent(object):
         buff.writeIndentedLines(code)
 
     def writeEndCodeJS(self, buff):
-
-        endLoopInteration = ("\nfunction endLoopIteration(thisScheduler, loop) {\n"
+        endLoopInteration = ("\nfunction endLoopIteration(scheduler, snapshot) {\n"
                     "  // ------Prepare for next entry------\n"
                     "  return function () {\n"
-                    "    if (typeof loop !== 'undefined') {\n"
+                    "    if (typeof snapshot !== 'undefined') {\n"
                     "      // ------Check if user ended loop early------\n"
-                    "      if (loop.finished) {\n"
+                    "      if (snapshot.finished) {\n"
                     "        // Check for and save orphaned data\n"
                     "        if (psychoJS.experiment.isEntryEmpty()) {\n"
-                    "          psychoJS.experiment.nextEntry(loop);\n"
+                    "          psychoJS.experiment.nextEntry(snapshot);\n"
                     "        }\n"
-                    "      thisScheduler.stop();\n"
+                    "        scheduler.stop();\n"
                     "      } else {\n"
-                    "        const thisTrial = loop.getCurrentTrial();\n"
+                    "        const thisTrial = snapshot.getCurrentTrial();\n"
                     "        if (typeof thisTrial === 'undefined' || !('isTrials' in thisTrial) || thisTrial.isTrials) {\n"
-                    "          psychoJS.experiment.nextEntry(loop);\n"
+                    "          psychoJS.experiment.nextEntry(snapshot);\n"
                     "        }\n"
                     "      }\n"
                     "    return Scheduler.Event.NEXT;\n"
@@ -843,9 +856,9 @@ class SettingsComponent(object):
                     "}\n")
         buff.writeIndentedLines(endLoopInteration)
 
-        recordLoopIterationFunc = ("\nfunction importConditions(trials) {\n"
+        recordLoopIterationFunc = ("\nfunction importConditions(currentLoop) {\n"
                     "  return function () {\n"
-                    "    psychoJS.importAttributes(trials.getCurrentTrial());\n"
+                    "    psychoJS.importAttributes(currentLoop.getCurrentTrial());\n"
                     "    return Scheduler.Event.NEXT;\n"
                     "    };\n"
                     "}\n")
